@@ -483,7 +483,7 @@ tp_call_stream_init_known_interfaces (void)
       tp_proxy_or_subclass_hook_on_interface_add (tp_type,
           tp_cli_call_stream_add_signals);
       tp_proxy_subclass_add_error_mapping (tp_type,
-          TP_ERROR_PREFIX, TP_ERRORS, TP_TYPE_ERROR);
+          TP_ERROR_PREFIX, TP_ERROR, TP_TYPE_ERROR);
 
       g_once_init_leave (&once, 1);
     }
@@ -510,7 +510,7 @@ tp_call_stream_get_feature_quark_core (void)
  *
  * <!-- -->
  *
- * Returns: the value of #TpCallStream:local-seding-state
+ * Returns: the value of #TpCallStream:local-sending-state
  * Since: 0.17.5
  */
 TpSendingState
