@@ -18,6 +18,10 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+#if defined (TP_DISABLE_SINGLE_INCLUDE) && !defined (_TP_IN_META_HEADER) && !defined (_TP_COMPILATION)
+#error "Only <telepathy-glib/telepathy-glib.h> and <telepathy-glib/telepathy-glib-dbus.h> can be included directly."
+#endif
+
 #ifndef __TP_CONTACT_H__
 #define __TP_CONTACT_H__
 
@@ -26,6 +30,7 @@
 
 #include <telepathy-glib/capabilities.h>
 #include <telepathy-glib/connection.h>
+#include <telepathy-glib/defs.h>
 #include <telepathy-glib/handle.h>
 
 #include <telepathy-glib/_gen/genums.h>
@@ -67,10 +72,13 @@ typedef enum {
     TP_CONTACT_FEATURE_CONTACT_GROUPS,
     TP_CONTACT_FEATURE_CONTACT_BLOCKING,
 } TpContactFeature;
-#define NUM_TP_CONTACT_FEATURES (TP_CONTACT_FEATURE_CONTACT_BLOCKING + 1)
+#define TP_NUM_CONTACT_FEATURES (TP_CONTACT_FEATURE_CONTACT_BLOCKING + 1)
+#define NUM_TP_CONTACT_FEATURES TP_NUM_CONTACT_FEATURES
 #define TP_CONTACT_FEATURE_INVALID ((TpContactFeature) -1)
 
 /* Basic functionality, always available */
+_TP_AVAILABLE_IN_0_20
+TpAccount *tp_contact_get_account (TpContact *self);
 TpConnection *tp_contact_get_connection (TpContact *self);
 TpHandle tp_contact_get_handle (TpContact *self);
 const gchar *tp_contact_get_identifier (TpContact *self);
@@ -89,6 +97,8 @@ const gchar *tp_contact_get_presence_message (TpContact *self);
 
 /* TP_CONTACT_FEATURE_LOCATION */
 GHashTable *tp_contact_get_location (TpContact *self);
+_TP_AVAILABLE_IN_0_20
+GVariant *tp_contact_dup_location (TpContact *self);
 
 /* TP_CONTACT_FEATURE_CAPABILITIES */
 TpCapabilities *tp_contact_get_capabilities (TpContact *self);
@@ -98,7 +108,13 @@ GFile *tp_contact_get_avatar_file (TpContact *self);
 const gchar *tp_contact_get_avatar_mime_type (TpContact *self);
 
 /* TP_CONTACT_FEATURE_INFO */
+#ifndef TP_DISABLE_DEPRECATED
+_TP_DEPRECATED_IN_0_20_FOR (tp_contact_dup_contact_info)
 GList *tp_contact_get_contact_info (TpContact *self);
+#endif
+
+_TP_AVAILABLE_IN_0_20
+GList *tp_contact_dup_contact_info (TpContact *self);
 
 void tp_contact_request_contact_info_async (TpContact *self,
     GCancellable *cancellable, GAsyncReadyCallback callback,
@@ -130,11 +146,13 @@ void tp_contact_set_contact_groups_async (TpContact *self,
 gboolean tp_contact_set_contact_groups_finish (TpContact *self,
     GAsyncResult *result, GError **error);
 
+#ifndef TP_DISABLE_DEPRECATED
 typedef void (*TpConnectionContactsByHandleCb) (TpConnection *connection,
     guint n_contacts, TpContact * const *contacts,
     guint n_failed, const TpHandle *failed,
     const GError *error, gpointer user_data, GObject *weak_object);
 
+_TP_DEPRECATED_IN_0_20
 void tp_connection_get_contacts_by_handle (TpConnection *self,
     guint n_handles, const TpHandle *handles,
     guint n_features, const TpContactFeature *features,
@@ -145,6 +163,7 @@ typedef void (*TpConnectionUpgradeContactsCb) (TpConnection *connection,
     guint n_contacts, TpContact * const *contacts,
     const GError *error, gpointer user_data, GObject *weak_object);
 
+_TP_DEPRECATED_IN_0_20_FOR(tp_connection_upgrade_contacts_async)
 void tp_connection_upgrade_contacts (TpConnection *self,
     guint n_contacts, TpContact * const *contacts,
     guint n_features, const TpContactFeature *features,
@@ -156,17 +175,46 @@ typedef void (*TpConnectionContactsByIdCb) (TpConnection *connection,
     const gchar * const *requested_ids, GHashTable *failed_id_errors,
     const GError *error, gpointer user_data, GObject *weak_object);
 
+_TP_DEPRECATED_IN_0_20_FOR(tp_connection_get_contact_by_id_async)
 void tp_connection_get_contacts_by_id (TpConnection *self,
     guint n_ids, const gchar * const *ids,
     guint n_features, const TpContactFeature *features,
     TpConnectionContactsByIdCb callback,
     gpointer user_data, GDestroyNotify destroy, GObject *weak_object);
+#endif
 
 TpContact *tp_connection_dup_contact_if_possible (TpConnection *connection,
     TpHandle handle, const gchar *identifier);
 
+_TP_AVAILABLE_IN_0_20
+void tp_connection_dup_contact_by_id_async (TpConnection *self,
+    const gchar *id,
+    guint n_features,
+    const TpContactFeature *features,
+    GAsyncReadyCallback callback,
+    gpointer user_data);
+_TP_AVAILABLE_IN_0_20
+TpContact *tp_connection_dup_contact_by_id_finish (TpConnection *self,
+    GAsyncResult *result,
+    GError **error);
+
+_TP_AVAILABLE_IN_0_20
+void tp_connection_upgrade_contacts_async (TpConnection *self,
+    guint n_contacts,
+    TpContact * const *contacts,
+    guint n_features,
+    const TpContactFeature *features,
+    GAsyncReadyCallback callback,
+    gpointer user_data);
+_TP_AVAILABLE_IN_0_20
+gboolean tp_connection_upgrade_contacts_finish (TpConnection *self,
+    GAsyncResult *result,
+    GPtrArray **contacts,
+    GError **error);
+
 /* TP_CONTACT_FEATURE_CONTACT_BLOCKING */
 
+_TP_AVAILABLE_IN_0_18
 gboolean tp_contact_is_blocked (TpContact *self);
 
 G_END_DECLS
