@@ -39,6 +39,7 @@
 #include <telepathy-glib/dbus.h>
 #include <telepathy-glib/gtypes.h>
 #include <telepathy-glib/util.h>
+#include <telepathy-glib/variant-util-internal.h>
 
 #define DEBUG_FLAG TP_DEBUG_MISC
 #include "telepathy-glib/debug-internal.h"
@@ -127,7 +128,7 @@ tp_message_init (TpMessage *self)
  * <!-- nothing more to say -->
  *
  * Returns: a newly allocated message suitable to be passed to
- * tp_message_mixin_take_received
+ * tp_message_mixin_take_received()
  *
  * Since: 0.7.21
  * Deprecated: since 0.13.9. Use tp_cm_message_new()
@@ -199,6 +200,29 @@ tp_message_peek (TpMessage *self,
   return g_ptr_array_index (self->parts, part);
 }
 
+/**
+ * tp_message_dup_part:
+ * @self: a message
+ * @part: a part number
+ *
+ * <!-- nothing more to say -->
+ *
+ * Returns: (transfer full):
+ *  the current contents of the given part, or %NULL if the part number is
+ *  out of range
+ *
+ * Since: 0.19.10
+ */
+GVariant *
+tp_message_dup_part (TpMessage *self,
+    guint part)
+{
+  if (part >= self->parts->len)
+    return NULL;
+
+  return _tp_asv_to_vardict (g_ptr_array_index (self->parts, part));
+}
+
 
 /**
  * tp_message_append_part:
@@ -245,7 +269,7 @@ tp_message_delete_part (TpMessage *self,
  * tp_message_ref_handle:
  * @self: a message
  * @handle_type: a handle type, greater than %TP_HANDLE_TYPE_NONE and less than
- *  %NUM_TP_HANDLE_TYPES
+ *  %TP_NUM_HANDLE_TYPES
  * @handle: a handle of the given type
  *
  * Reference the given handle until this message is destroyed.
@@ -590,13 +614,15 @@ tp_message_set_bytes (TpMessage *self,
  * @part: a part number, which must be strictly less than the number
  *  returned by tp_message_count_parts()
  * @key: a key in the mapping representing the part
- * @source: a value
+ * @source: a value, encoded as dbus-glib would
  *
  * Set @key in part @part of @self to have a copy of @source as its value.
  *
  * If @source represents a data structure containing handles, they should
  * all be referenced with tp_message_ref_handle() first.
  *
+ * In high-level language bindings, use tp_message_set_variant() instead.
+ *
  * Since: 0.7.21
  */
 void
@@ -614,6 +640,43 @@ tp_message_set (TpMessage *self,
       g_strdup (key), tp_g_value_slice_dup (source));
 }
 
+/**
+ * tp_message_set_variant:
+ * @self: a message
+ * @part: a part number, which must be strictly less than the number
+ *  returned by tp_message_count_parts()
+ * @key: a key in the mapping representing the part
+ * @value: a value
+ *
+ * Set @key in part @part of @self to have @value as its value.
+ *
+ * If @value is a floating reference (see g_variant_ref_sink()), then this
+ * function will take ownership of it.
+ *
+ * Since: 0.19.10
+ */
+void
+tp_message_set_variant (TpMessage *self,
+    guint part,
+    const gchar *key,
+    GVariant *value)
+{
+  GValue *gvalue;
+
+  g_return_if_fail (part < self->parts->len);
+  g_return_if_fail (key != NULL);
+  g_return_if_fail (value != NULL);
+  g_return_if_fail (self->priv->mutable);
+
+  g_variant_ref_sink (value);
+  gvalue = g_slice_new0 (GValue);
+  dbus_g_value_parse_g_variant (value, gvalue);
+  g_variant_unref (value);
+
+  g_hash_table_insert (g_ptr_array_index (self->parts, part),
+      g_strdup (key), gvalue);
+}
+
 /**
  * tp_message_take_message:
  * @self: a #TpCMMessage
