@@ -19,6 +19,10 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+#if defined (TP_DISABLE_SINGLE_INCLUDE) && !defined (_TP_IN_META_HEADER) && !defined (_TP_COMPILATION)
+#error "Only <telepathy-glib/telepathy-glib.h> and <telepathy-glib/telepathy-glib-dbus.h> can be included directly."
+#endif
+
 #ifndef __TP_UTIL_H__
 #define __TP_UTIL_H__
 #define __TP_IN_UTIL_H__
@@ -34,6 +38,10 @@ G_BEGIN_DECLS
 gboolean tp_g_ptr_array_contains (GPtrArray *haystack, gpointer needle);
 void tp_g_ptr_array_extend (GPtrArray *target, GPtrArray *source);
 
+#ifndef __GI_SCANNER__
+/* Functions with _new in their names confuse the g-i scanner, but these
+ * are all (skip)'d anyway. */
+
 GValue *tp_g_value_slice_new (GType type) G_GNUC_WARN_UNUSED_RESULT;
 
 GValue *tp_g_value_slice_new_boolean (gboolean b) G_GNUC_WARN_UNUSED_RESULT;
@@ -58,6 +66,8 @@ GValue *tp_g_value_slice_new_static_boxed (GType type, gconstpointer p)
 GValue *tp_g_value_slice_new_take_boxed (GType type, gpointer p)
   G_GNUC_WARN_UNUSED_RESULT;
 
+#endif
+
 void tp_g_value_slice_free (GValue *value);
 
 GValue *tp_g_value_slice_dup (const GValue *value) G_GNUC_WARN_UNUSED_RESULT;
@@ -65,10 +75,8 @@ GValue *tp_g_value_slice_dup (const GValue *value) G_GNUC_WARN_UNUSED_RESULT;
 void tp_g_hash_table_update (GHashTable *target, GHashTable *source,
     GBoxedCopyFunc key_dup, GBoxedCopyFunc value_dup);
 
-#define tp_str_empty(s) (tp_str_empty_inline (s))
-
 static inline gboolean
-tp_str_empty_inline (const gchar *s)
+tp_str_empty (const gchar *s)
 {
   return (s == NULL || s[0] == '\0');
 }
